@@ -8,7 +8,11 @@ then
   virtualenv $venv_name
 fi
 . ${virtualenv_activate}
-
+pip install --upgrade pip
+pip install --upgrade setuptools
+pip install --upgrade wheel
+pip install -r requirements.txt
+pip install -r test-requirements.txt
 if [[ -e "./setup.py" ]]
 then
     python setup.py develop
